/* XPM */
static const char * none_default_xpm[] = {
"144 96 149 2",
"  	c None",
". 	c #4E4E4E",
"+ 	c #181818",
"@ 	c #717171",
"# 	c #5D5D5D",
"$ 	c #616161",
"% 	c #484848",
"& 	c #000000",
"* 	c #6E6E6E",
"= 	c #545454",
"- 	c #161616",
"; 	c #5B5B5B",
"> 	c #505050",
", 	c #464646",
"' 	c #191919",
") 	c #ABABAB",
"! 	c #373737",
"~ 	c #8C8C8C",
"{ 	c #121212",
"] 	c #101010",
"^ 	c #080808",
"/ 	c #606060",
"( 	c #272727",
"_ 	c #383838",
": 	c #696969",
"< 	c #747474",
"[ 	c #636363",
"} 	c #292929",
"| 	c #757575",
"1 	c #595959",
"2 	c #1E1E1E",
"3 	c #878787",
"4 	c #737373",
"5 	c #9F9F9F",
"6 	c #9D9D9D",
"7 	c #9C9C9C",
"8 	c #808080",
"9 	c #565656",
"0 	c #8A8A8A",
"a 	c #5F5F5F",
"b 	c #A4A4A4",
"c 	c #151515",
"d 	c #535353",
"e 	c #AFAFAF",
"f 	c #929292",
"g 	c #959595",
"h 	c #4A4A4A",
"i 	c #777777",
"j 	c #1D1D1D",
"k 	c #6B6B6B",
"l 	c #404040",
"m 	c #9E9E9E",
"n 	c #494949",
"o 	c #A8A8A8",
"p 	c #686868",
"q 	c #3C3C3C",
"r 	c #797979",
"s 	c #848484",
"t 	c #242424",
"u 	c #939393",
"v 	c #8B8B8B",
"w 	c #4D4D4D",
"x 	c #1B1B1B",
"y 	c #A9A9A9",
"z 	c #0E0E0E",
"A 	c #787878",
"B 	c #828282",
"C 	c #515151",
"D 	c #0C0C0C",
"E 	c #979797",
"F 	c #6F6F6F",
"G 	c #6D6D6D",
"H 	c #7D7D7D",
"I 	c #ADADAD",
"J 	c #5C5C5C",
"K 	c #212121",
"L 	c #424242",
"M 	c #262626",
"N 	c #555555",
"O 	c #4B4B4B",
"P 	c #050505",
"Q 	c #323232",
"R 	c #7A7A7A",
"S 	c #3A3A3A",
"T 	c #7C7C7C",
"U 	c #909090",
"V 	c #8D8D8D",
"W 	c #666666",
"X 	c #8F8F8F",
"Y 	c #767676",
"Z 	c #ACACAC",
"` 	c #898989",
" .	c #818181",
"..	c #303030",
"+.	c #868686",
"@.	c #888888",
"#.	c #2A2A2A",
"$.	c #454545",
"%.	c #838383",
"&.	c #3E3E3E",
"*.	c #1F1F1F",
"=.	c #131313",
"-.	c #A1A1A1",
";.	c #5E5E5E",
">.	c #676767",
",.	c #0A0A0A",
"'.	c #A3A3A3",
").	c #363636",
"!.	c #919191",
"~.	c #9A9A9A",
"{.	c #202020",
"].	c #AAAAAA",
"^.	c #A7A7A7",
"/.	c #2C2C2C",
"(.	c #727272",
"_.	c #313131",
":.	c #6C6C6C",
"<.	c #3F3F3F",
"[.	c #343434",
"}.	c #A2A2A2",
"|.	c #252525",
"1.	c #1A1A1A",
"2.	c #585858",
"3.	c #626262",
"4.	c #5A5A5A",
"5.	c #646464",
"6.	c #989898",
"7.	c #6A6A6A",
"8.	c #969696",
"9.	c #8E8E8E",
"0.	c #3B3B3B",
"a.	c #282828",
"b.	c #4F4F4F",
"c.	c #7F7F7F",
"d.	c #474747",
"e.	c #949494",
"f.	c #9B9B9B",
"g.	c #4C4C4C",
"h.	c #333333",
"i.	c #414141",
"j.	c #AEAEAE",
"k.	c #575757",
"l.	c #7B7B7B",
"m.	c #858585",
"n.	c #999999",
"o.	c #2F2F2F",
"p.	c #A5A5A5",
"q.	c #A6A6A6",
"r.	c #434343",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                  . + + + + + + + + + + @                                   # # # # # # # # # # # $                                                 7 ~ ~ ~ ~ ~ ~ o                                                                         # # # # # # # # # # # $             ",
"                                  % & & & & & & & & & & *                                   & & & & & & & & & & & +                                                 ..& & & & & & b                                                                         & & & & & & & & & & & +             ",
"                                  = - & & & & & & & & & *                                   & & & & & & & & & & & +                                               g & & & & & & $.                %./ &.*.P & =.} O : f                                     & & & & & & & & & & & +             ",
"                                      ; & & & & & & & & *                                   > , ' & & & & & & & & +                                               a & & & & & & 8           -.;.] & & & & & & & & & & & t @                                 > , ' & & & & & & & & +             ",
"                                      ) & & & & & & & & *                                       ) ! & & & & & & & +                                               ' & & & & & c           >.,.& & & & & & & & & & & & & & & j H                                 ) ! & & & & & & & +             ",
"                                        & & & & & & & & *                                         ~ & & & & & & & +                                             %.& & & & & & ;       '.).& & & & & & & & & & & & & & & & & & & w                                 ~ & & & & & & & +             ",
"                                        & & & & & & & & *                                           & & & & & & & +                                             h & & & & & & !.    ~.{.& & & & & & & & & & & & & & & & & & & & & Q ].                              & & & & & & & +             ",
"                                        & & & & & & & & *                                           & & & & & & & +                                           ^.& & & & & & /.    5 2 & & & & & & & & & & ^ j & & & & & & & & & & & ).                              & & & & & & & +             ",
"          { { { { { { { { { { { { { { ] & & & & & & & & ^ { { { { { { { { { { { { { { /             & & & & & & & +                                           (.& & & & & & *     _.& & & & & & & & c :.m       !.; & & & & & & & & & =                             & & & & & & & +             ",
"          & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & #             & & & & & & & +                                           _.& & & & & & b   $ & & & & & & & & <.^.              g t & & & & & & & & [._ _ _ _ _ _ _ _ _ _ _ _ ).& & & & & & & +             ",
"          & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & #             & & & & & & & +                                         g & & & & & & $.  m P & & & & & & & L                     }.|.& & & & & & & & & & & & & & & & & & & & & & & & & & & & +             ",
"          & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & #             & & & & & & & +                                         / & & & & & & 8   J & & & & & & & {.o                       f P & & & & & & & & & & & & & & & & & & & & & & & & & & & +             ",
"          & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & #             & & & & & & & +                                         1.& & & & & c     c & & & & & & & r                           ; & & & & & & & & & & & & & & & & & & & & & & & & & & & +             ",
"          { { { { { { { ^ & & & & & & & & & & & & & & & & & & & & & & & ] { { { { { { /             & & & & & & & +                                       %.& & & & & & ;   X & & & & & & & '                             m & & & & & & & & & & & & & & & & & & & & & & & & & & & +             ",
"                        ( & & & & & & & & & _ : < [ } & & & & & & & & & |                           & & & & & & & +                                       O & & & & & & !.  < & & & & & & & C                               /.& & & & & & & & & & & & & & & & & & & & & & & & & & +             ",
"                      1 & & & & & & & & 2 3           4 ^ & & & & & & & ] 5                         & & & & & & & +                                     o P & & & & & /.    $ & & & & & & & F                               d & & & & & & & A                     j.& & & & & & & +             ",
"                    6 & & & & & & & & 2 7               8 & & & & & & & & 9                         & & & & & & & +                                     (.& & & & & & *     2.& & & & & & & R                               $ & & & & & & & @                       & & & & & & & +             ",
"                    ; & & & & & & & & 0                   a & & & & & & & ^ b                       & & & & & & & & { { { { { { { { 3.                  _.& & & & & & b     4.& & & & & & & A                               ;.& & & & & & & (.                      & & & & & & & +             ",
"                    c & & & & & & & d                     e - & & & & & & & |                       & & & & & & & & & & & & & & & & /                 g & & & & & & $.      5.& & & & & & & k                               . & & & & & & & H                       & & & & & & & +             ",
"                  f & & & & & & & & g                       / & & & & & & & h                       & & & & & & & & & & & & & & & & /                 / & & & & & & 8       r & & & & & & & $.                              2 & & & & & & & j M M M M M M M M M M t & & & & & & & +             ",
"                  i & & & & & & & j                         3 & & & & & & & 2                       & & & & & & & & & & & & & & & & /                 1.& & & & & c         6.& & & & & & & D ].                          U & & & & & & & & & & & & & & & & & & & & & & & & & & & +             ",
"                  k & & & & & & & l                         m & & & & & & & &                       & & & & & & & & & & & & & & & & /               %.& & & & & & ;           t & & & & & & & >.                          , & & & & & & & & & & & & & & & & & & & & & & & & & & & +             ",
"                  $ & & & & & & & n                         o & & & & & & & &                       & & & & & & & & & & & & & & & & /               O & & & & & & !.          7.& & & & & & & ,.8.                      T & & & & & & & & & & & & & & & & & & & & & & & & & & & & +             ",
"                  p & & & & & & & q                         m & & & & & & & &                       & & & & & & & -                               o P & & & & & /.            ].=.& & & & & & & } }.                  V ] & & & & & & & & & & & & & & & & & & & & & & & & & & & & +             ",
"                  r & & & & & & & {                         s & & & & & & & t                       & & & & & & & +                               4 & & & & & & *               < & & & & & & & & |.9.              A D & & & & & & & & + + + + + + + + + + + + + - & & & & & & & +             ",
"                  u & & & & & & & & v                       ; & & & & & & & w                       & & & & & & & +                               Q & & & & & & b                 % & & & & & & & & & O  .~.b 8.Y ! & & & & & & & & & k                             & & & & & & & +             ",
"                    x & & & & & & & %                     y z & & & & & & & A                       & & & & & & & +                             8.& & & & & & $.                  I ).& & & & & & & & & & & & & & & & & & & & & & & C                               & & & & & & & +             ",
"                    [ & & & & & & & & B                   C & & & & & & & z )                       & & & & & & & +                             / & & & & & & 8                     ) 0.& & & & & & & & & & & & & & & & & & & & & =                                 & & & & & & & +             ",
"                    b D & & & & & & & - E               F & & & & & & & & [                         & & & & & & & +                             1.& & & & & c                           N & & & & & & & & & & & & & & & & & & ^ (.                                  & & & & & & & +             ",
"                      G & & & & & & & & + H         I J & & & & & & & & K I                         & & & & & & & +                           s & & & & & & ;                             %.a.& & & & & & & & & & & & & & & L 7                                     & & & & & & & +             ",
"                        L & & & & & & & & & M N / O z & & & & & & & & P ~                           & & & & & & & +                           O & & & & & & !.                                T S & & & & & & & & & & D b.U                                         & & & & & & & +             ",
"                        ) Q & & & & & & & & & & & & & & & & & & & & & R                             & & & & & & & +                         o P & & & & & /.                                      }.c.[ . L &.d.= G @.                                              & & & & & & & +             ",
"                          y S & & & & & & & & & & & & & & & & & & ^ T                               & & & & & & & +                         4 & & & & & & *                                                                                                         & & & & & & & +             ",
"                              ; & & & & & & & & & & & & & & & & ( U                                 & & & & & & & +                         Q & & & & & & b                                                                           ].e.+. .%.v 6                 & & & & & & & +             ",
"                                V _ & & & & & & & & & & & & { W                                     & & & & & & & +                       8.& & & & & & $.                                                                      !.$ /.& & & & & & & ] $.i Z         & & & & & & & +             ",
"                                    X J M & & & & & & D L Y Z                                       & & & & & & & +                       / & & & & & & 8                                                                   0 _ & & & & & & & & & & & & & ] 3.)                                 ",
"                                          o u ` 3 V 6                                               & & & & & & & +                       1.& & & & & c                                                                 ) C & & & & & & & & & & & & & & & & & x B                               ",
"                                                                                                    & & & & & & & +                     s & & & & & & ;                                                               f.#.& & & & & & & & & & & & & & & & & & & & 5.                            ",
"                                                                                                    & & & & & & & +                     g.& & & & & & !.                                                            E 1.& & & & & & & & & & & & & & & & & & & & & & k.                          ",
"                                                                                                    & & & & & & & +                   o P & & & & & /.                                                            '.*.& & & & & & & & & |.N 5.;.$.^ & & & & & & & & & [                         ",
"                                                                                                    & & & & & & & +                   4 & & & & & & *                                                             0.& & & & & & & & [.~           I p D & & & & & & & & s                       ",
"                               .K K K K K K K K K K K w                                             & & & & & & & +                   h.& & & & & & b                                                           | & & & & & & & & b.                  !.x & & & & & & & {.                      ",
"                              H & & & & & & & & & & & L                                             & & & & & & & +                 8.& & & & & & $.                                                            2 & & & & & & & i.                      !.^ & & & & & & & F                     ",
"                              H & & & & & & & & & & & L                                             & & & & & & & +                 $ & & & & & & 8                                                           8 & & & & & & & D b                         7.& & & & & & & a.                    ",
"                              5 H F ..& & & & & & & & L                                             +.+.+.+.+.+.+.@.                x & & & & & c                                                             C & & & & & & & J                           I { & & & & & & & 6.                  ",
"                                      #.& & & & & & & L                                                                           s & & & & & & ;                                                             {.& & & & & & & 0                             g.& & & & & & & i                   ",
"                                      :.& & & & & & & L                                                                           g.& & & & & & !.                                                            & & & & & & & & )                             F & & & & & & & $                   ",
"                                      R & & & & & & & L                                                                         o P & & & & & /.                                                            p.& & & & & & & &                               T & & & & & & & k.                  ",
"                                      l.& & & & & & & L                                                                         4 & & & & & & *                                                             p.& & & & & & & &                               T & & & & & & & k.                  ",
"                                      l.& & & & & & & L                                                                         h.& & & & & & b                                                               & & & & & & & & )                             F & & & & & & & $                   ",
"                                      l.& & & & & & & L                                                                       8.& & & & & & $.                                                                {.& & & & & & & v                             w & & & & & & & i                   ",
"                                      l.& & & & & & & L                                                                       $ & & & & & & 8                                                                 C & & & & & & & ;.                          j.=.& & & & & & & 6.                  ",
"                                      l.& & & & & & & L                                                                       x & & & & & c                                                                   c.& & & & & & & z q.                        :.& & & & & & & (                     ",
"                                      l.& & & & & & & L                                                                     m.& & & & & & ;                                                                     j & & & & & & & $.                      e.,.& & & & & & & F                     ",
"                                      l.& & & & & & & M I                                                                   w & & & & & & !.                                                                    < & & & & & & & & d                   g {.& & & & & & & *.                      ",
"                                      T & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & /     y P & & & & & /.                                                                        S & & & & & & & & _ X             :.] & & & & & & & & %.                      ",
"                                      B & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & /     < & & & & & & *                                                                         }.j & & & & & & & & & #.2.>.$ n D & & & & & & & & & $                         ",
"                                      n.& & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & /     [.& & & & & & b                                                                           g ' & & & & & & & & & & & & & & & & & & & & & & N                           ",
"                                        o.& & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & /   E & & & & & & $.                                                                              n.a.& & & & & & & & & & & & & & & & & & & & $                             ",
"                                        f =.& & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & /   -.@.@.@.@.@.@.5                                                                                 ].. & & & & & & & & & & & & & & & & & 1.8                               ",
"                                          -./ Q - ,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.$                                                                                                       @.).& & & & & & & & & & & & & z / ].                                ",
"                                                                                                                                                                                                                                !.a } & & & & & & & z r.Y )                                     ",
"                                                                                                                                                                                                                                      ].u +.8 %.0 7                                             ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                "};

/* XPM */
const static char * hangul_default_xpm[] = {
"144 96 116 2",
"  	c None",
". 	c #4F4F4F",
"+ 	c #1B1B1B",
"@ 	c #6F6F6F",
"# 	c #5D5D5D",
"$ 	c #616161",
"% 	c #494949",
"& 	c #000000",
"* 	c #6C6C6C",
"= 	c #555555",
"- 	c #191919",
"; 	c #5B5B5B",
"> 	c #515151",
", 	c #484848",
"' 	c #1C1C1C",
") 	c #9F9F9F",
"! 	c #3A3A3A",
"~ 	c #868686",
"{ 	c #151515",
"] 	c #131313",
"^ 	c #0A0A0A",
"/ 	c #606060",
"( 	c #2A2A2A",
"_ 	c #3B3B3B",
": 	c #686868",
"< 	c #717171",
"[ 	c #626262",
"} 	c #2C2C2C",
"| 	c #727272",
"1 	c #595959",
"2 	c #212121",
"3 	c #818181",
"4 	c #707070",
"5 	c #969696",
"6 	c #949494",
"7 	c #939393",
"8 	c #7C7C7C",
"9 	c #565656",
"0 	c #848484",
"a 	c #5E5E5E",
"b 	c #9A9A9A",
"c 	c #181818",
"d 	c #545454",
"e 	c #A3A3A3",
"f 	c #5F5F5F",
"g 	c #8A8A8A",
"h 	c #8D8D8D",
"i 	c #4B4B4B",
"j 	c #747474",
"k 	c #202020",
"l 	c #828282",
"m 	c #696969",
"n 	c #424242",
"o 	c #959595",
"p 	c #9D9D9D",
"q 	c #676767",
"r 	c #3F3F3F",
"s 	c #757575",
"t 	c #7F7F7F",
"u 	c #272727",
"v 	c #8C8C8C",
"w 	c #858585",
"x 	c #4E4E4E",
"y 	c #1F1F1F",
"z 	c #9E9E9E",
"A 	c #111111",
"B 	c #7E7E7E",
"C 	c #525252",
"D 	c #A0A0A0",
"E 	c #0F0F0F",
"F 	c #8F8F8F",
"G 	c #6D6D6D",
"H 	c #6B6B6B",
"I 	c #797979",
"J 	c #A2A2A2",
"K 	c #5C5C5C",
"L 	c #252525",
"M 	c #444444",
"N 	c #292929",
"O 	c #4D4D4D",
"P 	c #070707",
"Q 	c #353535",
"R 	c #767676",
"S 	c #3C3C3C",
"T 	c #787878",
"U 	c #898989",
"V 	c #878787",
"W 	c #646464",
"X 	c #888888",
"Y 	c #737373",
"Z 	c #8B8B8B",
"` 	c #7D7D7D",
" .	c #333333",
"..	c #808080",
"+.	c #2D2D2D",
"@.	c #6A6A6A",
"#.	c #777777",
"$.	c #919191",
"%.	c #161616",
"&.	c #979797",
"*.	c #0D0D0D",
"=.	c #7B7B7B",
"-.	c #585858",
";.	c #9B9B9B",
">.	c #929292",
",.	c #666666",
"'.	c #636363",
").	c #454545",
"!.	c #383838",
"~.	c #2B2B2B",
"{.	c #575757",
"].	c #999999",
"^.	c #313131",
"/.	c #1E1E1E",
"(.	c #A1A1A1",
"_.	c #5A5A5A",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                          . + + + + + + + + + + @                                   # # # # # # # # # # # $                                                                                                                                                                     ",
"                                          % & & & & & & & & & & *                                   & & & & & & & & & & & +                                                                                                                                                                     ",
"                                          = - & & & & & & & & & *                                   & & & & & & & & & & & +                                         ~ # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # [                                 ",
"                                              ; & & & & & & & & *                                   > , ' & & & & & & & & +                                         | & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & J                               ",
"                                              ) & & & & & & & & *                                       ) ! & & & & & & & +                                         | & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & J                               ",
"                                                & & & & & & & & *                                         ~ & & & & & & & +                                         | & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & J                               ",
"                                                & & & & & & & & *                                           & & & & & & & +                                         | & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & J                               ",
"                                                & & & & & & & & *                                           & & & & & & & +                                         | & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & J                               ",
"                  { { { { { { { { { { { { { { ] & & & & & & & & ^ { { { { { { { { { { { { { { /             & & & & & & & +                                         o ` ` ` ` ` ` ` ` ` ` ` ` ` ` ` ` ` ` ` ` ` ` ` ` ` ` ` ` ` ` ` ` ` ` ` =.-.& & & & & & & & J                               ",
"                  & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & #             & & & & & & & +                                                                                                                   ;.& & & & & & & & J                               ",
"                  & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & #             & & & & & & & +                                                                                                                   z & & & & & & & & J                               ",
"                  & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & #             & & & & & & & +                                                                                                                   z & & & & & & & & J                               ",
"                  & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & #             & & & & & & & +                                                                                                                   z & & & & & & & & J                               ",
"                  { { { { { { { ^ & & & & & & & & & & & & & & & & & & & & & & & ] { { { { { { /             & & & & & & & +                                                                                                                   p & & & & & & & & J                               ",
"                                ( & & & & & & & & & _ : < [ } & & & & & & & & & |                           & & & & & & & +                                                                                                                   ;.& & & & & & & &                                 ",
"                              1 & & & & & & & & 2 3           4 ^ & & & & & & & ] 5                         & & & & & & & +                                                                                                                   &.& & & & & & & &                                 ",
"                            6 & & & & & & & & 2 7               8 & & & & & & & & 9                         & & & & & & & +                                                                                                                   >.& & & & & & & &                                 ",
"                            ; & & & & & & & & 0                   a & & & & & & & ^ b                       & & & & & & & & { { { { { { { { $                                                                                                 U & & & & & & & E                                 ",
"                            c & & & & & & & d                     e - & & & & & & & |                       & & & & & & & & & & & & & & & & f                                                                                                 B & & & & & & & (                                 ",
"                          g & & & & & & & & h                       / & & & & & & & i                       & & & & & & & & & & & & & & & & f                                                                                                 H & & & & & & & M                                 ",
"                          j & & & & & & & k                         l & & & & & & & 2                       & & & & & & & & & & & & & & & & f                                                                                                 , & & & & & & & ,.                                ",
"                          m & & & & & & & n                         o & & & & & & & &                       & & & & & & & & & & & & & & & & f                                                                                                 { & & & & & & & U                                 ",
"                          $ & & & & & & & i                         p & & & & & & & &                       & & & & & & & & & & & & & & & & f                                                                                               < & & & & & & & S                                   ",
"                          q & & & & & & & r                         6 & & & & & & & &                       & & & & & & & -                             '.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.L & & & & & & & ).'.'.'.'.'.'.'.0                   ",
"                          s & & & & & & & {                         t & & & & & & & u                       & & & & & & & +                             & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & :                   ",
"                          v & & & & & & & & w                       ; & & & & & & & x                       & & & & & & & +                             & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & :                   ",
"                            y & & & & & & & %                     z A & & & & & & & s                       & & & & & & & +                             & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & :                   ",
"                            [ & & & & & & & & B                   C & & & & & & & A D                       & & & & & & & +                             & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & :                   ",
"                            b E & & & & & & & - F               G & & & & & & & & [                         & & & & & & & +                             & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & :                   ",
"                              H & & & & & & & & + I         J K & & & & & & & & L J                         & & & & & & & +                             X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X &.                  ",
"                                M & & & & & & & & & N 9 f O A & & & & & & & & P ~                           & & & & & & & +                                                                                                                                                                     ",
"                                ) Q & & & & & & & & & & & & & & & & & & & & & R                             & & & & & & & +                                                                                                                                                                     ",
"                                  z S & & & & & & & & & & & & & & & & & & ^ T                               & & & & & & & +                                                                                                                                                                     ",
"                                      ; & & & & & & & & & & & & & & & & ( U                                 & & & & & & & +                                                                                                                                                                     ",
"                                        V _ & & & & & & & & & & & & { W                                     & & & & & & & +                                                                                                                                                                     ",
"                                            X K N & & & & & & E M Y D                                       & & & & & & & +                                         0 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * G )                                 ",
"                                                  p Z 0 l V 6                                               & & & & & & & +                                         f & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & t                                 ",
"                                                                                                            & & & & & & & +                                         f & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & t                                 ",
"                                                                                                            & & & & & & & +                                         f & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & t                                 ",
"                                                                                                            & & & & & & & +                                         f & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & t                                 ",
"                                                                                                            & & & & & & & +                                         W k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k ^ & & & & & & & t                                 ",
"                                      ` L L L L L L L L L L L x                                             & & & & & & & +                                                                                                                   M & & & & & & & t                                 ",
"                                      I & & & & & & & & & & & M                                             & & & & & & & +                                                                                                                   M & & & & & & & t                                 ",
"                                      I & & & & & & & & & & & M                                             & & & & & & & +                                                                                                                   M & & & & & & & t                                 ",
"                                      5 I G  .& & & & & & & & M                                             ..............l                                                                                                                   M & & & & & & & t                                 ",
"                                              +.& & & & & & & M                                                                                                     Z g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g !.& & & & & & & t                                 ",
"                                              @.& & & & & & & M                                                                                                     k & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & t                                 ",
"                                              #.& & & & & & & M                                                                                                     k & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & t                                 ",
"                                              #.& & & & & & & M                                                                                                     k & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & t                                 ",
"                                              #.& & & & & & & M                                                                                                       $.. & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & t                                 ",
"                                              #.& & & & & & & M                                                                                                           ~.& & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & A 6                                 ",
"                                              #.& & & & & & & M                                                                                                           {.& & & & & & & ; ].].].].].].].].].].].].].].].].].].].].].].].].].].].].].].].].                                    ",
"                                              #.& & & & & & & M                                                                                                           f & & & & & & & '.                                                                                                    ",
"                                              #.& & & & & & & M                                                                                                           f & & & & & & & '.                                                                                                    ",
"                                              #.& & & & & & & N J                                                                                                         f & & & & & & & '.                                                                                                    ",
"                                              T & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & f                                             f & & & & & & & '.                                                                                                    ",
"                                              B & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & f                                             $ & & & & & & & ' ^.^.^.^.^.^.^.^.^.^.^.^.^.^.^.^.^.^.^.^.^.^.^.^.^.^.^.^.^.^.^.^.^.^.                                ",
"                                              $.& & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & f                                             @.& & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & &                                 ",
"                                                 .& & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & f                                             t & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & &                                 ",
"                                                g %.& & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & f                                               /.& & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & &                                 ",
"                                                  &./ Q - *.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*./                                               0 c & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & &                                 ",
"                                                                                                                                                                              (.I '._.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                "};

/* XPM */
const static char * english_default_xpm[] = {
"144 96 138 2",
"  	c None",
". 	c #5D5D5D",
"+ 	c #616161",
"@ 	c #000000",
"# 	c #1B1B1B",
"$ 	c #7F7F7F",
"% 	c #606060",
"& 	c #404040",
"* 	c #232323",
"= 	c #070707",
"- 	c #161616",
"; 	c #2C2C2C",
"> 	c #4C4C4C",
", 	c #686868",
"' 	c #8B8B8B",
") 	c #979797",
"! 	c #131313",
"~ 	c #272727",
"{ 	c #6F6F6F",
"] 	c #515151",
"^ 	c #484848",
"/ 	c #1C1C1C",
"( 	c #666666",
"_ 	c #0D0D0D",
": 	c #202020",
"< 	c #797979",
"[ 	c #9F9F9F",
"} 	c #3A3A3A",
"| 	c #999999",
"1 	c #383838",
"2 	c #4E4E4E",
"3 	c #868686",
"4 	c #919191",
"5 	c #242424",
"6 	c #353535",
"7 	c #9E9E9E",
"8 	c #969696",
"9 	c #212121",
"0 	c #0A0A0A",
"a 	c #343434",
"b 	c #181818",
"c 	c #6A6A6A",
"d 	c #949494",
"e 	c #8A8A8A",
"f 	c #5B5B5B",
"g 	c #555555",
"h 	c #414141",
"i 	c #9C9C9C",
"j 	c #8D8D8D",
"k 	c #373737",
"l 	c #3B3B3B",
"m 	c #959595",
"n 	c #444444",
"o 	c #989898",
"p 	c #282828",
"q 	c #5C5C5C",
"r 	c #9D9D9D",
"s 	c #757575",
"t 	c #898989",
"u 	c #717171",
"v 	c #525252",
"w 	c #2F2F2F",
"x 	c #6D6D6D",
"y 	c #545454",
"z 	c #A2A2A2",
"A 	c #585858",
"B 	c #777777",
"C 	c #5A5A5A",
"D 	c #5E5E5E",
"E 	c #636363",
"F 	c #696969",
"G 	c #4F4F4F",
"H 	c #474747",
"I 	c #292929",
"J 	c #8F8F8F",
"K 	c #0F0F0F",
"L 	c #8E8E8E",
"M 	c #787878",
"N 	c #727272",
"O 	c #878787",
"P 	c #191919",
"Q 	c #4A4A4A",
"R 	c #7C7C7C",
"S 	c #929292",
"T 	c #9A9A9A",
"U 	c #737373",
"V 	c #3D3D3D",
"W 	c #565656",
"X 	c #707070",
"Y 	c #2B2B2B",
"Z 	c #454545",
"` 	c #939393",
" .	c #3C3C3C",
"..	c #505050",
"+.	c #7B7B7B",
"@.	c #626262",
"#.	c #494949",
"$.	c #6B6B6B",
"%.	c #828282",
"&.	c #8C8C8C",
"*.	c #818181",
"=.	c #858585",
"-.	c #747474",
";.	c #A0A0A0",
">.	c #848484",
",.	c #1F1F1F",
"'.	c #7E7E7E",
").	c #2D2D2D",
"!.	c #1E1E1E",
"~.	c #3E3E3E",
"{.	c #676767",
"].	c #434343",
"^.	c #151515",
"/.	c #4D4D4D",
"(.	c #9B9B9B",
"_.	c #111111",
":.	c #2A2A2A",
"<.	c #888888",
"[.	c #4B4B4B",
"}.	c #838383",
"|.	c #5F5F5F",
"1.	c #808080",
"2.	c #7A7A7A",
"3.	c #323232",
"4.	c #313131",
"5.	c #333333",
"6.	c #7D7D7D",
"7.	c #424242",
"8.	c #595959",
"9.	c #303030",
"0.	c #535353",
"a.	c #3F3F3F",
"b.	c #252525",
"c.	c #363636",
"d.	c #393939",
"e.	c #6C6C6C",
"f.	c #6E6E6E",
"g.	c #767676",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                        . . . . . . . . . . . +                                                                                                               2.. . . . . . . . . . . m                         ",
"                                                                                                        @ @ @ @ @ @ @ @ @ @ @ #                                                                                                               f @ @ @ @ @ @ @ @ @ @ @ <.                        ",
"                                              $ % & * = @ - ; > , '                                     @ @ @ @ @ @ @ @ @ @ @ #                                                                                                               f @ @ @ @ @ @ @ @ @ @ @ <.                        ",
"                                        ) . ! @ @ @ @ @ @ @ @ @ @ @ ~ {                                 ] ^ / @ @ @ @ @ @ @ @ #                                                                                                               -.G 3.@ @ @ @ @ @ @ @ @ <.                        ",
"                                      ( _ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ : <                                 [ } @ @ @ @ @ @ @ #                                                                                                                     $.@ @ @ @ @ @ @ @ <.                        ",
"                                  | 1 @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ 2                                 3 @ @ @ @ @ @ @ #                                                       i R + > } 4.5.~.v c >.                                          4.@ @ @ @ @ @ @ <.                        ",
"                                4 5 @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ 6 7                               @ @ @ @ @ @ @ #                                                   6.7.@ @ @ @ @ @ @ @ @ @ @ ^.A L                                     W @ @ @ @ @ @ @ <.                        ",
"                              8 9 @ @ @ @ @ @ @ @ @ @ 0 : @ @ @ @ @ @ @ @ @ @ @ 1                               @ @ @ @ @ @ @ #                                               >.3.@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ ..|                                 f @ @ @ @ @ @ @ <.                        ",
"                              a @ @ @ @ @ @ @ @ b c d       e f @ @ @ @ @ @ @ @ @ g                             @ @ @ @ @ @ @ #                                             8.@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ - <                               f @ @ @ @ @ @ @ <.                        ",
"                            % @ @ @ @ @ @ @ @ h i               j ~ @ @ @ @ @ @ @ @ k l l l l l l l l l l l l 1 @ @ @ @ @ @ @ #                                         r l @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ %                             f @ @ @ @ @ @ @ <.                        ",
"                          m = @ @ @ @ @ @ @ n                     o p @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ #                                       r 9.@ @ @ @ @ @ @ @ @ @ @ / _.@ @ @ @ @ @ @ @ @ @ @ W                           f @ @ @ @ @ @ @ <.                        ",
"                          q @ @ @ @ @ @ @ 5 r                       e = @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ #                                       1 @ @ @ @ @ @ @ @ @ y =.      [ +.n @ @ @ @ @ @ @ @ @ +                         f @ @ @ @ @ @ @ <.                        ",
"                          b @ @ @ @ @ @ @ s                           f @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ #                                     0.@ @ @ @ @ @ @ @ ; <.                B - @ @ @ @ @ @ @ @ R                       f @ @ @ @ @ @ @ <.                        ",
"                        t @ @ @ @ @ @ @ /                             m @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ #                                   $ @ @ @ @ @ @ @ @ w (.                    O K @ @ @ @ @ @ @ ,.7                     f @ @ @ @ @ @ @ <.                        ",
"                        u @ @ @ @ @ @ @ v                               w @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ #                                   I @ @ @ @ @ @ @ / o                         2.@ @ @ @ @ @ @ @ D                     f @ @ @ @ @ @ @ <.                        ",
"                        % @ @ @ @ @ @ @ x                               y @ @ @ @ @ @ @ s                     z @ @ @ @ @ @ @ #                                 B @ @ @ @ @ @ @ @ +.                            [.@ @ @ @ @ @ @ _ r                   f @ @ @ @ @ @ @ <.                        ",
"                        A @ @ @ @ @ @ @ B                               % @ @ @ @ @ @ @ {                       @ @ @ @ @ @ @ #                                  .@ @ @ @ @ @ @ 7.                              8 @ @ @ @ @ @ @ @ {                   f @ @ @ @ @ @ @ <.                        ",
"                        C @ @ @ @ @ @ @ s                               D @ @ @ @ @ @ @ {                       @ @ @ @ @ @ @ #                               o @ @ @ @ @ @ @ @ *.                                /.@ @ @ @ @ @ @ a.                  f @ @ @ @ @ @ @ <.                        ",
"                        E @ @ @ @ @ @ @ F                               G @ @ @ @ @ @ @ <                       @ @ @ @ @ @ @ #                               2.@ @ @ @ @ @ @ #                                   $ @ @ @ @ @ @ @ @                   f @ @ @ @ @ @ @ <.                        ",
"                        s @ @ @ @ @ @ @ H                               9 @ @ @ @ @ @ @ : I I I I I I I I I I ~ @ @ @ @ @ @ @ #                               @.@ @ @ @ @ @ @ G                                   r @ @ @ @ @ @ @ @ u >.>.>.>.>.>.>.>.#.@ @ @ @ @ @ @ <.                        ",
"                        J @ @ @ @ @ @ @ K [                           t @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ #                               G @ @ @ @ @ @ @ c                                     b.@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ <.                        ",
"                          ~ @ @ @ @ @ @ @ (                           ^ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ #                               n @ @ @ @ @ @ @ -.                                    1 @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ <.                        ",
"                          , @ @ @ @ @ @ @ _ L                       M @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ #                               & @ @ @ @ @ @ @ M                                     7.@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ <.                        ",
"                          [ - @ @ @ @ @ @ @ ; o                   3 ! @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ #                               H @ @ @ @ @ @ @ X                                     c.@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ <.                        ",
"                            N @ @ @ @ @ @ @ @ p O               s K @ @ @ @ @ @ @ @ # # # # # # # # # # # # # P @ @ @ @ @ @ @ #                               W @ @ @ @ @ @ @ E                                     ,.@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ <.                        ",
"                              Q @ @ @ @ @ @ @ @ @ > R S T L U } @ @ @ @ @ @ @ @ @ F                             @ @ @ @ @ @ @ #                               $.@ @ @ @ @ @ @ a.                                  ) @ @ @ @ @ @ @ @ /.0.0.0.0.0.0.0.0.).@ @ @ @ @ @ @ <.                        ",
"                              z 1 @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ v                               @ @ @ @ @ @ @ #                               =.@ @ @ @ @ @ @ = z                                 M @ @ @ @ @ @ @ b.                  f @ @ @ @ @ @ @ <.                        ",
"                                [ V @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ g                                 @ @ @ @ @ @ @ #                                 ! @ @ @ @ @ @ @ u                                 ~.@ @ @ @ @ @ @ f                   f @ @ @ @ @ @ @ <.                        ",
"                                    W @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ 0 X                                   @ @ @ @ @ @ @ #                                 W @ @ @ @ @ @ @ ).                              e @ @ @ @ @ @ @ @ }.                  f @ @ @ @ @ @ @ <.                        ",
"                                      $ Y @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ Z `                                     @ @ @ @ @ @ @ #                                 j @ @ @ @ @ @ @ @ ,                             c.@ @ @ @ @ @ @ d.                    f @ @ @ @ @ @ @ <.                        ",
"                                          M  .@ @ @ @ @ @ @ @ @ @ K ..t                                         @ @ @ @ @ @ @ #                                   2 @ @ @ @ @ @ @ 0 t                         @.@ @ @ @ @ @ @ @ 1.                    f @ @ @ @ @ @ @ <.                        ",
"                                              o +.@.G n & #.g $.%.                                              @ @ @ @ @ @ @ #                                   | - @ @ @ @ @ @ @ # J                     e.@ @ @ @ @ @ @ @ [.                      f @ @ @ @ @ @ @ <.                        ",
"                                                                                                                @ @ @ @ @ @ @ #                                     +.@ @ @ @ @ @ @ @ ! U               [ v @ @ @ @ @ @ @ @ p [                       f @ @ @ @ @ @ @ <.                        ",
"                                                                                  [ &.*.R $ =.d                 @ @ @ @ @ @ @ #                                       {.@ @ @ @ @ @ @ @ @ ; F %.L e R g ! @ @ @ @ @ @ @ @ - '                         f @ @ @ @ @ @ @ <.                        ",
"                                                                            e % w @ @ @ @ @ @ @ ! H -.;.        @ @ @ @ @ @ @ #                                         E @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ # '                           f @ @ @ @ @ @ @ <.                        ",
"                                                                        >.l @ @ @ @ @ @ @ @ @ @ @ @ @ ! + ;.                                                              u = @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ ; J                             f @ @ @ @ @ @ @ <.                        ",
"                                                                    ;.v @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ ,.'.                                                              e 9.@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ 8.                                f @ @ @ @ @ @ @ <.                        ",
"                                                                  S ).@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ E                                                                 f.* @ @ @ @ @ @ @ @ @ @ @ @ @ @ H 3                                   f @ @ @ @ @ @ @ <.                        ",
"                                                                J !.@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ A                                                                   R 2 b @ @ @ @ @ @ @ @ c.+ J                                       f @ @ @ @ @ @ @ <.                        ",
"                                                              | * @ @ @ @ @ @ @ @ @ p g E . H 0 @ @ @ @ @ @ @ @ @ @.                                                                      S *.g.N g.$ <.7                                             f @ @ @ @ @ @ @ <.                        ",
"                                                              ~.@ @ @ @ @ @ @ @ k =.          z {.K @ @ @ @ @ @ @ @ $                                                                                                                                 f @ @ @ @ @ @ @ <.                        ",
"                                                            N @ @ @ @ @ @ @ @ ..                  e ,.@ @ @ @ @ @ @ 5                                                                                                                                 f @ @ @ @ @ @ @ <.                        ",
"                                                            9 @ @ @ @ @ @ @ ].                      e 0 @ @ @ @ @ @ @ x                                                                                                                               f @ @ @ @ @ @ @ <.                        ",
"                                                          +.@ @ @ @ @ @ @ K T                         , @ @ @ @ @ @ @ Y                                                                                                                               f @ @ @ @ @ @ @ <.                        ",
"                                                          v @ @ @ @ @ @ @ q                           z ^.@ @ @ @ @ @ @ J                                                                                                                             f @ @ @ @ @ @ @ <.                        ",
"                                                          5 @ @ @ @ @ @ @ >.                            /.@ @ @ @ @ @ @ -.                                                                                                                            f @ @ @ @ @ @ @ <.                        ",
"                                                          @ @ @ @ @ @ @ @ [                             x @ @ @ @ @ @ @ +                                                                                                                             f @ @ @ @ @ @ @ <.                        ",
"                                                        (.@ @ @ @ @ @ @ @                               M @ @ @ @ @ @ @ A                                                                                                                             f @ @ @ @ @ @ @ <.                        ",
"                                                        (.@ @ @ @ @ @ @ @                               M @ @ @ @ @ @ @ A                                                                                                                             f @ @ @ @ @ @ @ <.                        ",
"                                                          @ @ @ @ @ @ @ @ ;.                            x @ @ @ @ @ @ @ +                                                                                                                             f @ @ @ @ @ @ @ <.                        ",
"                                                          5 @ @ @ @ @ @ @ =.                            2 @ @ @ @ @ @ @ -.                                                                                                                            f @ @ @ @ @ @ @ <.                        ",
"                                                          v @ @ @ @ @ @ @ .                           z - @ @ @ @ @ @ @ J                                                                                                                             f @ @ @ @ @ @ @ <.                        ",
"                                                          +.@ @ @ @ @ @ @ _.i                         c @ @ @ @ @ @ @ :.                                                                                                                              f @ @ @ @ @ @ @ <.                        ",
"                                                            : @ @ @ @ @ @ @ H                       &._ @ @ @ @ @ @ @ x                                                                                                                               f @ @ @ @ @ @ @ <.                        ",
"                                                            u @ @ @ @ @ @ @ @ y                   j 5 @ @ @ @ @ @ @ *                                                                                                                                 f @ @ @ @ @ @ @ <.                        ",
"                                                               .@ @ @ @ @ @ @ @ l <.            c ! @ @ @ @ @ @ @ @ '.                                                                                                                                f @ @ @ @ @ @ @ <.                        ",
"                                                              o : @ @ @ @ @ @ @ @ @ ).A ( + [.K @ @ @ @ @ @ @ @ @ %                                                                                                                                   f @ @ @ @ @ @ @ <.                        ",
"                                                                j / @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ g                                                                                                                                     f @ @ @ @ @ @ @ <.                        ",
"                                                                  4 Y @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ %                                                                                                                                       f @ @ @ @ @ @ @ <.                        ",
"                                                                    [ G @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ !.R                                                                                                                                         f @ @ @ @ @ @ @ <.                        ",
"                                                                        }.1 @ @ @ @ @ @ @ @ @ @ @ @ @ _.|.[                                                                                                                                           f @ @ @ @ @ @ @ <.                        ",
"                                                                            e D ; @ @ @ @ @ @ @ _.Z U ;.                                                                                                                                              B A A A A A A A `                         ",
"                                                                                  7 ' 1.R '.>.`                                                                                                                                                                                                 ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                ",
"                                                                                                                                                                                                                                                                                                "};
